;************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;************************************************

begin

;**************   READ IN FILES   ***************
 f = addfile("data/tas_Amon_MPI-ESM-LR_CELUrcp45_r1i1p1_200601-210012_yearmean_globmean.nc","r")
 f_ctrl  = addfile("data/tas_Amon_MPI-ESM-LR_esmrcp85_r1i1p1_200601-210012_yearmean_globmean.nc","r")
 f_hist  = addfile("data/tas_Amon_MPI-ESM-LR_esmHistorical_r1i1p1_2005_yearmean_globmean.nc","r")
 f_rcp45 = addfile("data/tas_Amon_MPI-ESM-LR_rcp45_r1i1p1_200601-210012_yearmean_globmean.nc","r")

; ************ READ IN VARIABLES  ***************

 temp_CE=f->tas(:,0,0)
 temp_ctrl=f_ctrl->tas(:,0,0)
 temp_hist=f_hist->tas(:,0,0)
 temp_rcp45 = f_rcp45->tas(:,0,0)

 temp_CE_run=runave(temp_CE,5,0)
 temp_ctrl_run=runave(temp_ctrl,5,0)
 temp_rcp45_run=runave(temp_rcp45,5,0)

 time=f_ctrl->time

 temp = new((/6,dimsizes(time)/),typeof(temp_ctrl))
 temp(4,:) = temp_ctrl - temp_hist(0)
 temp(5,:) = temp_ctrl_run - temp_hist(0)
 temp(2,:) = temp_CE - temp_hist(0)
 temp(3,:) = temp_CE_run - temp_hist(0) 
 temp(0,:) = temp_rcp45 - temp_hist(0)
 temp(1,:) = temp_rcp45_run - temp_hist(0)

 utc_d = cd_calendar(time,0)
 years=utc_d(:,0)
 
;**********  OPEN GRAPHICS WORKSTATION *********
 wks_type = "eps"
 wks = gsn_open_wks(wks_type,"Figure2B")
;**********  GENERAL PLOT SETTINGS  ************
 
 xyres                 = True         ; xy plot mods desired
 xyres@vpHeightF       = 0.55             
 xyres@vpWidthF        = 0.75
 xyres@xyMonoDashPattern  = True
 xyres@xyLineColors = (/"green","green","blue","blue","black","black"/)
 xyres@xyLineThicknesses = (/2.,4.,2.,4.,2.,4./)
 xyres@tiMainString     = "Global mean SAT - HIST (2005) / K"  
 xyres@tiMainFontHeightF = 0.031
 xyres@trYMinF  = -0.2
 xyres@trYMaxF  = 4.4
 xyres@tmXBLabelFontHeightF = 0.028
 xyres@tmYLLabelFontHeightF = 0.028
 xyres@pmLegendDisplayMode    = "Always" 
 xyres@pmLegendSide           = "Top"               ; Change location of 
 xyres@pmLegendParallelPosF   = .33                  ; move units right
 xyres@pmLegendOrthogonalPosF = -0.6                ; move units down
 xyres@pmLegendWidthF         = 0.1                ; Change width and
 xyres@pmLegendHeightF        = 0.25                ; height of legend.
 xyres@lgPerimOn              = False               ; turn off box around
 xyres@lgLabelFontHeightF     = .024                 ; label font height
 xyres@xyExplicitLegendLabels = (/"  rcp45","  rcp45 5-yr running mean","  FOR","  FOR 5-yr running mean","  REF","  REF 5-yr running mean"/)
 xyres@lgItemOrder  = (/ 1,0,3,2,5,4 /)   ; Reorder the legends

 plot= gsn_csm_xy(wks,years,temp,xyres)
 
 
end
